@@ -570,8 +570,18 @@ udp_tl_send_message(osip_transaction_t * tr, osip_message_t * sip, char *host,
     }
   
   OSIP_TRACE (osip_trace (__FILE__, __LINE__, OSIP_INFO1, NULL,
-                          "Message sent: \n%s (to dest=%s:%i)\n",
-                          message, ipbuf, port));
+                          "Message sent: (to dest=%s:%i)\n%s\n",
+                          ipbuf, port, message));
+
+  if (tr!=NULL)
+    {
+      if (tr->ict_context != NULL)
+	osip_ict_set_destination (tr->ict_context,
+				  osip_strdup (ipbuf), port);
+      if (tr->nict_context != NULL)
+	osip_nict_set_destination (tr->nict_context,
+				   osip_strdup (ipbuf), port);
+    }
 
   if (0 >
       sendto (udp_socket, (const void *) message, length, 0,
@@ -598,7 +608,7 @@ udp_tl_send_message(osip_transaction_t * tr, osip_message_t * sip, char *host,
 	  
 #ifndef MINISIZE
 	  /* delete first SRV entry that is not reachable */
-	  if (tr->record.name[0]!='\0' && tr->record.srventry[0].srv[0]!='\0')
+	  if (tr!=NULL && tr->record.name[0]!='\0' && tr->record.srventry[0].srv[0]!='\0')
 	    {
 	      memmove(&tr->record.srventry[0], &tr->record.srventry[1], 9*sizeof(osip_srv_entry_t));
 	      memset(&tr->record.srventry[9], 0, sizeof(osip_srv_entry_t));
